# Generated by Django 4.2 on 2023-04-26 15:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('drf_cms', '0001_initial'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='text',
            unique_together={('page', 'key')},
        ),
        migrations.RemoveField(
            model_name='text',
            name='site',
        ),
    ]
